#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-ID7uSRwWwVQACrPzWo2dCj
key:                  pager-0.1.1.0-ID7uSRwWwVQACrPzWo2dCj
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  deedd5fa05faa322d1da339c988026e3
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pager-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-ID7uSRwWwVQACrPzWo2dCj
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-F67YktQmHRqJ5R9QX7ucHV
    conduit-extra-1.3.8-6O6CtrkaMBHHbx4pVlP0Hf directory-1.3.8.5
    process-1.6.19.0 resourcet-1.2.6-LJgXHkWLt2tDuo3wpypfir
    safe-0.3.21-GLTVOu0sarW6Z7N465j1G9 terminfo-0.4.1.6 text-2.0.2
    transformers-0.6.1.0 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

